==> cancer_researcher_ai-0.1.tar.gz: cancer_researcher_ai-0.1/README.md <==

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# Cancer Researcher AI

![cancer_chatbot](openart-image_lEFwQqVA_1727547070986_raw.jpg)

## Overview
Cancer Researcher AI is an interactive application designed to provide users with information related to cancer. It utilizes natural language processing and machine learning techniques to answer questions, provide resources, and assist users in understanding cancer-related topics.

GitHub link: [Link](https://github.com/Kirankkt/Cancer_Researcher_AI)

## Features
- **Natural Language Understanding**: The chatbot can comprehend and respond to user inquiries about cancer types, treatments, symptoms.
- **Interactive Conversations**: Users can engage in dynamic conversations, receiving tailored responses based on their questions.
- **Resource Links**: Provides links to reliable cancer-related resources from journal articles.

## Technologies Used
- **Python**: The primary programming language used for developing the chatbot.
- **LangChain**: For managing conversations and utilizing language models.
- **FAISS**: For efficient similarity search and retrieval of information from a knowledge base.

## Disclaimer:
-The Chatbot is not a substitute for professional medical advice, diagnosis, or treatment. Users should consult healthcare professionals for any medical concerns.

## User installation
To run the Cancer Chatbot locally, follow these steps:

   ```bash
  pip install cancer_researcher_ai
   ```

## Running the Chatbot
To start the chatbot, run the following command in terminal:
```bash
cancer_researcher_ai
```

## Usage
- Ask the chatbot questions about cancer.
- Receive information on various cancer topics, including symptoms, treatment options based on the current research findings.

## Contributing
Contributions are welcome! If you have suggestions for improvements or features, please create a pull request or open an issue.

## License
This project is licensed under the GPL License. See the [LICENSE](LICENSE.txt) file for details.


## History of the Cancer Chatbot

The Cancer Chatbot project was initiated by Akshay PR and Kiran KKT in (2024) with the goal of providing an AI-powered assistant to help answer common cancer-related queries based on reliable medical information. The project was born out of a desire to create a user-friendly tool for cancer research and inspired from [perplexity](https://www.perplexity.ai/).

### Key Milestones:
- **[09 2024]**: Initial concept and prototype developed.


As we bring in more contributors, the project remains rooted in its mission to provide accessible and reliable information backed by links to the source documents.


## Contact
For any inquiries or feedback, please contact Kiran or Akshay: [Akshay P R](mailto:akshaypr314159@gmail.com) / [KiranKKT](mailto:akshaypr314159@gmail.com).

-----------------------------------------------------------------------------------------------------------------------------------------------------------------------

==> cancer_researcher_ai-0.2.1.tar.gz: cancer_researcher_ai-0.2.1/README.md <==

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

# Cancer Researcher AI

![cancer_chatbot](https://raw.githubusercontent.com/Dorcatz123/Cancer_Researcher_AI/main/openart-image_lEFwQqVA_1727547070986_raw.jpg)

## Overview
Cancer Researcher AI is an interactive application designed to provide users with information related to cancer. It utilizes natural language processing and machine learning techniques to answer questions, provide resources, and assist users in understanding cancer-related topics.

GitHub link: [Link](https://github.com/Kirankkt/Cancer_Researcher_AI)

## Features
- **Natural Language Understanding**: The chatbot can comprehend and respond to user inquiries about cancer types, treatments, symptoms.
- **Interactive Conversations**: Users can engage in dynamic conversations, receiving tailored responses based on their questions.
- **Resource Links**: Provides links to reliable cancer-related resources from journal articles.

## Technologies Used
- **Python**: The primary programming language used for developing the chatbot.
- **LangChain**: For managing conversations and utilizing language models.
- **FAISS**: For efficient similarity search and retrieval of information from a knowledge base.

## Disclaimer:
-The Chatbot is not a substitute for professional medical advice, diagnosis, or treatment. Users should consult healthcare professionals for any medical concerns.

## User installation
To run the Cancer Chatbot locally, follow these steps:

   ```bash
  pip install --upgrade cancer_researcher_ai
   ```

## Running the Chatbot
To start the chatbot, run the following command in terminal:
```bash
cancer_researcher_ai
```

## Usage
- Ask the chatbot questions about cancer.
- Receive information on various cancer topics, including symptoms, treatment options based on the current research findings.

## Contributing
Contributions are welcome! If you have suggestions for improvements or features, create a pull request or open an issue in the GitHub page.

## License
This project is licensed under the MIT License. See the [LICENSE](LICENSE.txt) file for details.


## History of the Cancer Chatbot

The Cancer Chatbot project was initiated by Akshay PR and Kiran KKT in (2024) with the goal of providing an AI-powered assistant to help answer common cancer-related queries based on reliable medical information. The project was born out of a desire to create a user-friendly tool for cancer research.

### Key Milestones:
- **[09 2024]**: Initial concept and prototype developed.


As we bring in more contributors, the project remains rooted in its mission to provide accessible and reliable information backed by links to the source documents.


## Contact
For any inquiries or feedback, please contact Kiran or Akshay: [Akshay P R](mailto:akshaypr314159@gmail.com) / [KiranKKT](mailto:akshaypr314159@gmail.com).

-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
